# sundew ☀️
A new kind of testing framework for Python.

## Here Be Dragons 🐉
Not only does this project attempt a new approach to testing, it is also in _very_ early stages and thus still has alot of sharp edges. Early adopters are encouraged to try out sundew and report any issues or critical missing functionality in the form of a GitHub Issue. 

This project is maintained by a single part-time individual, so there is **no guarantee** on how quickly those will be addressed, however bug fixes and critical functionailty will be significantly prioritizd over expanded functionailty at this stage of the project. PRs are also welcome for those who are interested in [contributing](CONTRIBUTING.md).

If you are excited about trying something brand new and are willing to except the edges, please continue! However if you or your project is not ready to take on this amount of risk, I recommend keeping an eye on this project and waiting a bit before diving in. I'll update this section as the project matures.

## Documentation 📖
Documentation for sundew can be found [here](https://devenjarvis.github.io/sundew/)

